annalist
========

(Short README for PyPI - a longer version can be found at https://github.com/gklyne/annalist)

Free-form web data notebook - "Data management for little guys"

Goals
-----

A *Linked Data Notebook*, supporting collection, organization and sharing of structured and semi-structured data.  The name "annalist" derives from "`a person who writes annals <http://www.oxforddictionaries.com/definition/english/annalist>`_".

Goals:

* Easy data: out-of-box data acquisition, modification and organization of small data records.
* Flexible data: new record types and fields can be added as-required.
* Sharable data: use textual, easy to read file formats that can be shared by web, email, file transfer, version management system, memory stick, etc.
* Remixable data: records that can be first class participants in a wider ecosystem of linked data, with links in and links out.

Status
------

For current release status, see https://github.com/gklyne/annalist/blob/master/documents/release-notes/release-v0.1.md

